pub struct RpcList(pub Vec<Rpc>);Tuple Fields
0: Vec<Rpc>Trait Implementations
Sourceimpl Handler for RpcList
impl Handler for RpcList
Sourcefn call<'life0, 'life1, 'async_trait>(
&'life0 self,
method: &'life1 str,
params: Vec<Value>,
) -> Pin<Box<dyn Future<Output = Result<Value>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn call<'life0, 'life1, 'async_trait>(
&'life0 self,
method: &'life1 str,
params: Vec<Value>,
) -> Pin<Box<dyn Future<Output = Result<Value>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Performs a call against the servers in order, failing over to the next on transport errors. A JSON-RPC error response is returned immediately without failover, since it represents a valid answer from the server.